@@ -9,22 +9,29 @@ redundant <- function(cond, x = NULL, simplify = TRUE){
 # Generic function
 .redund <- function(x, cond, ...) UseMethod(".redund")
 
-# ==== Method for class 'tti' ====
+# ==== Method for class 'cti' ====
 # identifies the asf that are redundant within some csf
-#   x         tti
+#   x         cti
 #   cond      character vector with the csf
 #   simplify  output matrix instead of list if all csf have the same number of asf
-# value: A list of logical vectors (lengths corresponing to the number of asf), 
+# value: A list of logical vectors (lengths corresponding to the number of asf), 
 #        or a matrix if simplify=TRUE and all csf have the same number of asf
-.redund.tti <- function(x, cond, simplify = TRUE, full = FALSE, names = TRUE,
+.redund.cti <- function(x, cond, simplify = TRUE, full = FALSE, names = TRUE,
                         qc_full = qcond_csf(cond, sc, flat = TRUE)){
-  if (!full) x <- full.tt(x)
+  if (!full) x <- full.ct(x)
   sc <- x$scores
-  n <- nrow(sc)
-  ee <- matrix(qc_full[, 1L, ] == qc_full[, 2L, ], n)
-  colnames(ee) <- attr(qc_full, "condition")
-  lengths <- attr(qc_full, "csflengths")
-  out <- C_mredund(ee, lengths)
+  ok <- .qcondType(cond, colnames(sc), x$type, 
+                   stdComplex.multiple.only = FALSE) %in% c("stdAtomic", "stdComplex")
+  if (any(!ok)) 
+    stop("Invalid input to redundant:\n", paste0("  ", cond[!ok], collapse = "\n"),
+         call. = FALSE)
+  if (!length(cond)) return(logical(0))
+  asfs <- extract_asf(cond)
+  uasfs <- unique(unlist(asfs))
+  hmatches <- happly(asfs, match, table = uasfs)
+  qc <- qcond_asf(uasfs, sc, force.bool = TRUE)
+  mode(qc) <- "logical"
+  out <- lapply(hmatches, function(x) C_redund(qc[, x, drop = FALSE]))
   names(out) <- cond
   if (simplify && length(ul <- unique(lengths(out, use.names = FALSE))) == 1L){
     nms <- names(out)
@@ -34,31 +41,21 @@ redundant <- function(cond, x = NULL, simplify = TRUE){
   out
 }
 
-# ==== Method for class 'truthTab' ====
+# ==== Method for class 'configTable' ====
 # Function suited for interactive use
-.redund.truthTab <- function(x, cond, simplify = TRUE, full = FALSE){
-  tti <- tt.info(x)
-  ok <- .qcondType(cond, colnames(tti$scores), tti$type) %in% c("stdAtomic", "stdComplex")
-  if (any(!ok)) 
-    stop("Invalid input to redundant:\n", paste0("  ", cond[!ok], collapse = "\n"),
-         call. = FALSE)
-  .redund.tti(tti, cond, simplify = simplify, full = full) 
+.redund.configTable <- function(x, cond, simplify = TRUE, full = FALSE){
+  .redund.cti(ctInfo(x), cond, simplify = simplify, full = full) 
 }
 
 # ==== Default Method (for matrix or data.frame) ====
-# builds full.tt if x is NULL
-#   x       truthTab or NULL
-# value:    truthTab, mv if original is mv, cs else
+# builds full.ct if x is NULL
+#   x       configTable or NULL
+# value:    configTable, mv if original is mv, cs else
 .redund.default  <- function(x, cond, simplify = TRUE, ...){
   if (is.null(x)){
-    x <- full.tt.default(cond)
+    x <- full.ct.default(cond)
   } else {
-    x <- full.tt(x)
+    x <- full.ct(x)
   }
-  tti <- tt.info(x)
-  ok <- .qcondType(cond, colnames(tti$scores), tti$type) %in% c("stdAtomic", "stdComplex")
-  if (any(!ok)) 
-    stop("Invalid input to redundant:\n", paste0("  ", cond[!ok], collapse = "\n"),
-         call. = FALSE)
-  .redund.tti(tti, cond, simplify = simplify, full = TRUE)
+  .redund.cti(ctInfo(x), cond, simplify = simplify, full = TRUE)
 }
