@@ -1,166 +1,10 @@
 
 #include <Rcpp.h>
 #include "typedefs.h"
+#include "headers.h"
 
 using namespace Rcpp;
 
-//=============================================================================
-
-// Functions to manipulate intList's
-// ---------------------------------
-
-// Auxiliary fun used in isSubsetOf 
-IntegerVector rmFirst(IntegerVector x) {
-  int n = x.size();
-  IntegerVector out(n-1);
-  if (n>1) out = x[Range(1, n-1)];
-  return out;
-}
-
-// [[Rcpp::export]]
-bool C_isSubsetOf(IntegerVector x, IntegerVector y) {
-  int nx = x.size();
-  int ny = y.size();
-  int i=0, j=0;
-  bool out;
-  while (true) {
-    if (nx == i){
-      out = true;
-      break;
-    }
-    if (ny == j){
-      out = false;
-      break;
-    }
-    if (nx-i > ny-j){
-      out = false;
-      break;
-    }
-    int x1=x[i], y1=y[j];
-    if (x1 < y1){
-      out = false;
-      break;
-    }
-    if (x1 == y1){
-      ++i;
-    }
-    ++j;
-  }
-  return(out);
-}
-
-
-// [[Rcpp::export]]
-LogicalVector C_hasSupersetIn(intList x, intList y){
-  int ylen = y.size(), xlen = x.size();
-  //  Rcpp::Rcout << "The length of the 1st list is: " << ylen << std::endl;
-  //  Rcpp::Rcout << "The length of the 2nd list is: " << xlen << std::endl;
-  LogicalVector out(xlen);
-  for (int ix=0; ix<xlen; ix++) {
-    bool foundSuperset=false;
-    for (int iy=0; iy<ylen; iy++) {
-      if (C_isSubsetOf(x[ix], y[iy])){
-        foundSuperset=true;
-        break;
-      }
-    }    
-    out[ix]=foundSuperset;
-  }  
-  return out;
-}
-
-//// [[Rcpp::export]]
-bool C_allTRUE(LogicalVector x){
-  int len = x.size();
-  bool out = true;
-  for (int i=0; i<len; i++){
-    if (!x[i]){
-      out = false;
-      break;
-    }
-  }
-  return out;
-}
-//// [[Rcpp::export]]
-bool C_allFALSE(LogicalVector x){
-  int len = x.size();
-  bool out = true;
-  for (int i=0; i<len; i++){
-    if (x[i]){
-      out = false;
-      break;
-    }
-  }
-  return out;
-}
-
-// Determine if an intList x is minimal with respect to a reference intList
-// (ref contains existing solutions)
-// [[Rcpp::export]]
-bool C_intList_minimal(intList x, recIntList ref, bool ignore_equals=false){
-  int lenr = ref.size();
-  bool is_minimal = true;
-  for (int j=0; j<lenr; j++){
-    //Rcpp::Rcout << "j: " << j << std::endl;
-    LogicalVector lv = C_hasSupersetIn(as<intList>(ref[j]), x);
-    //Rcpp::Rcout << "lv: " << lv << std::endl;
-    if (C_allTRUE(lv)){ 
-      is_minimal = false;
-      if (ignore_equals){
-        bool eq = C_allTRUE(C_hasSupersetIn(x, as<intList>(ref[j])));
-        if (eq){ 
-          is_minimal = true;
-        }
-      }
-      //Rcpp::Rcout << "is_minimal: " << is_minimal << std::endl;
-      if (!is_minimal) break;
-    }
-  }
-  return(is_minimal);
-}
-
-
-// Determine the intLists in x that are minimal with respect to existing solutions ref
-// [[Rcpp::export]]
-LogicalVector C_minimal(recIntList x, recIntList ref, bool ignore_equals=false){
-  int lenx = x.size();
-  LogicalVector out(lenx);
-  for (int i=0; i<lenx; i++){
-    out[i] = C_intList_minimal(as<intList>(x[i]), ref, ignore_equals);  
-  }
-  return(out);
-}
-
-/*/ Print an intlist to the console
-// [[Rcpp::export]]
-void C_show_intList(intList x){
-  int lenx = x.size();
-  for (int i=0; i<lenx; i++){
-    IntegerVector xi = x[i];
-    Rcpp::Rcout << xi << " ";
-    if (i<lenx-1) Rcpp::Rcout << "/ ";
-  }
-  Rcpp::Rcout << std::endl;
-  return;
-}*/
-
-
-// paste two intList's
-// [[Rcpp::export]]
-intList C_paste_intList(intList x, intList y){
-  int lenx = x.size(), leny = y.size();
-  List out(lenx + leny);
-  for (int i=0; i<lenx; i++){
-    out[i] = x[i];
-  }
-  for (int i=0; i<leny; i++){
-    out[lenx + i] = y[i];
-  }
-  //  Rcpp::Rcout << as<intList>(out) << std::endl;
-  return(as<intList>(out));
-}
-
-
 //=============================================================================
 
 // Calculate con and cov of disjunctions
@@ -168,7 +12,7 @@ intList C_paste_intList(intList x, intList y){
 //   x   membership scores of antecendens
 //   y   membership scores of consequens
 // [[Rcpp::export]]
-NumericVector C_conCov(NumericVector x, NumericVector y, IntegerVector f){
+NumericVector C_conCov(const NumericVector x, const NumericVector y, const IntegerVector f){
   int n=x.size();
   NumericVector Sums(3), conCov(2);
   for (int i=0; i<n; i++){
@@ -187,7 +31,7 @@ NumericVector C_conCov(NumericVector x, NumericVector y, IntegerVector f){
 //   x    vector
 //   sub  subset of elements to consider
 // [[Rcpp::export]]
-double C_subsetMin(NumericVector x, IntegerVector sub){
+double C_subsetMin(const NumericVector x, const IntegerVector sub){
   int len = sub.size();
   double out = x(sub(0)-1);
   if (len == 1) return(out);
@@ -202,7 +46,7 @@ double C_subsetMin(NumericVector x, IntegerVector sub){
 //   m   IntegerMatrix, the rows representing the components of the conjunctions
 //   x  'scores'-matrix
 // [[Rcpp::export]]
-NumericMatrix C_conjScore(NumericMatrix x, IntegerMatrix m){
+NumericMatrix C_conjScore(const NumericMatrix x, const IntegerMatrix m){
   int n=x.nrow(), p=m.nrow();
   NumericMatrix out(n,p);
   for (int i=0; i<n; i++){
@@ -218,7 +62,7 @@ NumericMatrix C_conjScore(NumericMatrix x, IntegerMatrix m){
 
 // initialize ii
 // [[Rcpp::export]]
-IntegerVector C_init_ii(IntegerVector nn, LogicalVector st){
+IntegerVector C_init_ii(const IntegerVector nn, const LogicalVector st){
   int l=nn.size();
   IntegerVector ini(l);
   ini.fill(0);
@@ -232,7 +76,7 @@ IntegerVector C_init_ii(IntegerVector nn, LogicalVector st){
 
 // upper limit of ii
 // [[Rcpp::export]]
-IntegerVector C_set_lim(IntegerVector nn, LogicalVector st){
+IntegerVector C_set_lim(const IntegerVector nn, const LogicalVector st){
   int l=nn.size();
   IntegerVector lim(l);
   lim = nn - 1; 
@@ -247,7 +91,7 @@ IntegerVector C_set_lim(IntegerVector nn, LogicalVector st){
 
 // C_max_which
 // [[Rcpp::export]]
-int C_max_which(LogicalVector x) {
+int C_max_which(const LogicalVector x) {
   int n = x.size();
   int i;
   for (i=n-1; i >= 0; i--) {
@@ -259,7 +103,8 @@ int C_max_which(LogicalVector x) {
 
 // increment ii
 // [[Rcpp::export]]
-IntegerVector C_increment(IntegerVector ii, IntegerVector nn, LogicalVector st, IntegerVector lim){
+IntegerVector C_increment(IntegerVector ii, const IntegerVector nn, 
+                          const LogicalVector st, const IntegerVector lim){
   int l = ii.size();
   if (ii[l-1] < lim[l-1]){    // end of loop not yet reached in last position
     ii[l-1] += 1;
@@ -335,8 +180,10 @@ mytest(sample(c(1L, 2L, 3L, 3L, 4L, 5L, 5L, 5L, 6L, 7L)))
 
 // Find asf's of a given structure (=lengths of the conjunctions in the disjunctions)
 // [[Rcpp::export]]
-IntegerMatrix C_find_asf(IntegerVector conjlen, numMatList x, NumericVector y, IntegerVector f,
-                         double con = 1.0, double cov = 1.0, int maxSol = 1e6){
+IntegerMatrix C_find_asf(const IntegerVector conjlen, const numMatList x, 
+                         const NumericVector y, const IntegerVector f,
+                         const double con, const double cov, 
+                         const int maxSol){
   int n_conj = conjlen.size();
 
   // st = indicator, =true if conj hast same length as precedent conj
